@@ -290,7 +290,7 @@ public class CVSRepositoryLocation extends PlatformObject implements ICVSReposit
 					// Save options in hash table
 					StringTokenizer stOpt = new StringTokenizer(
 						location.substring(optionStart+1, end),
-            					"=;" //$NON-NLS-1$
+								"=;" //$NON-NLS-1$
 					);
 					while (stOpt.hasMoreTokens()) {
 						hmOptions.put(stOpt.nextToken(), stOpt.nextToken());
@@ -343,11 +343,11 @@ public class CVSRepositoryLocation extends PlatformObject implements ICVSReposit
 			end= location.indexOf(COLON, start);
 			int hostEnd = end;
 			if (end == -1) {
-			    // The last colon is optional so look for the slash that starts the path
-			    end = location.indexOf('/', start);
-			    hostEnd = end;
-			    // Decrement the end since the slash is part of the path
-			    if (end != -1) end--;
+				// The last colon is optional so look for the slash that starts the path
+				end = location.indexOf('/', start);
+				hostEnd = end;
+				// Decrement the end since the slash is part of the path
+				if (end != -1) end--;
 			}
 			String host = (hmOptions.containsKey("hostname")) ? hmOptions.get("hostname").toString() : location.substring(start, hostEnd); //$NON-NLS-1$ //$NON-NLS-2$
 			int port = USE_DEFAULT_PORT;
@@ -599,23 +599,17 @@ public class CVSRepositoryLocation extends PlatformObject implements ICVSReposit
 			root;
 	}
 	
-	/*
-	 * @see ICVSRepositoryLocation#getMethod()
-	 */
+	@Override
 	public IConnectionMethod getMethod() {
 		return method;
 	}
 
-	/*
-	 * @see ICVSRepositoryLocation#getPort()
-	 */
+	@Override
 	public int getPort() {
 		return port;
 	}
 	
-	/*
-	 * @see ICVSRepositoryLocation#getEncoding()
-	 */
+	@Override
 	public String getEncoding() {
 		if (hasPreferences()) {
 			return internalGetPreferences().get(PREF_SERVER_ENCODING, getDefaultEncoding());
@@ -624,9 +618,7 @@ public class CVSRepositoryLocation extends PlatformObject implements ICVSReposit
 		}
 	}
 
-	/*
-	 * @see ICVSRepositoryLocation#setEncoding()
-	 */
+	@Override
 	public void setEncoding(String encoding) {
 		if (encoding == null || encoding == getDefaultEncoding()) {
 			if (hasPreferences()) {
@@ -639,9 +631,7 @@ public class CVSRepositoryLocation extends PlatformObject implements ICVSReposit
 		}
 	}	
 
-	/*
-	 * @see ICVSRepositoryLocation#members(CVSTag, boolean, IProgressMonitor)
-	 */
+	@Override
 	public ICVSRemoteResource[] members(CVSTag tag, boolean modules, IProgressMonitor progress) throws CVSException {
 		try {
 			if (modules) {
@@ -668,16 +658,12 @@ public class CVSRepositoryLocation extends PlatformObject implements ICVSReposit
 		}
 	}
 	
-	/*
-	 * @see ICVSRepositoryLocation#getRemoteFolder(String, CVSTag)
-	 */
+	@Override
 	public ICVSRemoteFolder getRemoteFolder(String remotePath, CVSTag tag) {
 		return new RemoteFolder(null, this, remotePath, tag);		
 	}
 	
-	/*
-	 * @see ICVSRepositoryLocation#getRemoteFile(String, CVSTag)
-	 */
+	@Override
 	public ICVSRemoteFile getRemoteFile(String remotePath, CVSTag tag) {
 		IPath path = new Path(null, remotePath);
 		RemoteFolderTree remoteFolder = new RemoteFolderTree(null, this, path.removeLastSegments(1).toString(), tag);
@@ -686,9 +672,7 @@ public class CVSRepositoryLocation extends PlatformObject implements ICVSReposit
 		return remoteFile;
 	}
 	
-	/*
-	 * @see ICVSRepositoryLocation#getRootDirectory()
-	 */
+	@Override
 	public String getRootDirectory() {
 		return root;
 	}
@@ -703,17 +687,12 @@ public class CVSRepositoryLocation extends PlatformObject implements ICVSReposit
 		return CVSProviderPlugin.getPlugin().getTimeout();
 	}
 	
-	/*
-	 * @see ICVSRepositoryLocation#getUserInfo()
-	 */
+	@Override
 	public IUserInfo getUserInfo(boolean makeUsernameMutable) {
 		return new UserInfo(getUsername(), password, makeUsernameMutable ? true : isUsernameMutable());
 	}
 	
-	/*
-	 * @see ICVSRepositoryLocation#getUsername()
-	 * @see IUserInfo#getUsername()
-	 */
+	@Override
 	public String getUsername() {
 		// If the username is mutable, get it from the cache if it's there
 		if (user == null && isUsernameMutable()) {
@@ -722,9 +701,7 @@ public class CVSRepositoryLocation extends PlatformObject implements ICVSReposit
 		return user == null ? "" : user; //$NON-NLS-1$
 	}
 	
-	/*
-	 * @see IUserInfo#isUsernameMutable()
-	 */
+	@Override
 	public boolean isUsernameMutable() {
 		return !userFixed;
 	}
@@ -744,8 +721,8 @@ public class CVSRepositoryLocation extends PlatformObject implements ICVSReposit
 	 * for any connection made to this remote location.
 	 */
 	public Connection openConnection(IProgressMonitor monitor) throws CVSException {
-        // Get the lock for the host to ensure that we are not connecting to the same host concurrently.
-        Policy.checkCanceled(monitor);
+		// Get the lock for the host to ensure that we are not connecting to the same host concurrently.
+		Policy.checkCanceled(monitor);
 		ILock hostLock;
 		synchronized(hostLocks) {
 			hostLock = hostLocks.get(getHost());
@@ -755,11 +732,11 @@ public class CVSRepositoryLocation extends PlatformObject implements ICVSReposit
 			}
 		}
 		try {
-		    boolean acquired = false;
-		    int count = 0;
-		    int timeout = CVSProviderPlugin.getPlugin().getTimeout();
-		    while (!acquired) {
-		    	try {
+			boolean acquired = false;
+			int count = 0;
+			int timeout = CVSProviderPlugin.getPlugin().getTimeout();
+			while (!acquired) {
+				try {
 					acquired = hostLock.acquire(1000);
 				} catch (InterruptedException e) {
 					// Ignore
@@ -769,7 +746,7 @@ public class CVSRepositoryLocation extends PlatformObject implements ICVSReposit
 				}
 				count++;
 				Policy.checkCanceled(monitor);
-		    }
+			}
 			// Allow two ticks in case of a retry
 			monitor.beginTask(NLS.bind(CVSMessages.CVSRepositoryLocation_openingConnection, new String[] { getHost() }), 2);
 			ensureLocationCached();
@@ -796,9 +773,9 @@ public class CVSRepositoryLocation extends PlatformObject implements ICVSReposit
 					//	password = "";//$NON-NLS-1$ 
 					Connection connection = createConnection(password, monitor);
 					if (cacheNeedsUpdate)
-					    updateCachedLocation();
+						updateCachedLocation();
 					previousAuthenticationFailed = false;
-                    return connection;
+					return connection;
 				} catch (CVSAuthenticationException ex) {
 					previousAuthenticationFailed = true;
 					if (ex.getRetryStatus() == CVSAuthenticationException.RETRY) {
@@ -812,7 +789,7 @@ public class CVSRepositoryLocation extends PlatformObject implements ICVSReposit
 				}
 			}
 		} finally {
-            hostLock.release();
+			hostLock.release();
 			monitor.done();
 		}
 	}
@@ -828,76 +805,76 @@ public class CVSRepositoryLocation extends PlatformObject implements ICVSReposit
 		authenticator.promptForUserInfo(this, this, message);
 	}
 
-    /*
+	/*
 	 * Ensure that this location is in the known repositories list
 	 * and that the authentication information matches what is in the
 	 * cache, if this instance is not the instance in the cache.
-     */
-    private void ensureLocationCached() {
-        String location = getLocation();
-        KnownRepositories repositories = KnownRepositories.getInstance();
-        if (repositories.isKnownRepository(location)) {
-            try {
-                // The repository is already known.
-                // Ensure that the authentication information of this 
-                // location matches that of the known location
-                setAuthenticationInformation((CVSRepositoryLocation)repositories.getRepository(location));
-            } catch (CVSException e) {
-                // Log the exception and continue
-                CVSProviderPlugin.log(e);
-            }
-        } else {
-            // The repository is not known so record it so any authentication
-            // information the user may provide is remembered
-        	repositories.addRepository(this, true /* broadcast */);
-        }
-    }
+	 */
+	private void ensureLocationCached() {
+		String location = getLocation();
+		KnownRepositories repositories = KnownRepositories.getInstance();
+		if (repositories.isKnownRepository(location)) {
+			try {
+				// The repository is already known.
+				// Ensure that the authentication information of this 
+				// location matches that of the known location
+				setAuthenticationInformation((CVSRepositoryLocation)repositories.getRepository(location));
+			} catch (CVSException e) {
+				// Log the exception and continue
+				CVSProviderPlugin.log(e);
+			}
+		} else {
+			// The repository is not known so record it so any authentication
+			// information the user may provide is remembered
+			repositories.addRepository(this, true /* broadcast */);
+		}
+	}
 
 	/*
 	 * Set the authentication information of this instance such that it matches the
 	 * provided instances.
-     */
-    private void setAuthenticationInformation(CVSRepositoryLocation other) {
-        if (other != this) {
-            // The instances differ so copy from the other location to this one
-            if (other.getUserInfoCached()) {
-                // The user info is cached for the other instance
-                // so null all the values in this instance so the 
-                // information is obtained from the cache
-                this.allowCaching = true;
-                if (!userFixed) this.user = null;
-                if (!passwordFixed) this.password = null;
-            } else {
-                // The user info is not cached for the other instance so
-                // copy the authentication information into this instance
-                setAllowCaching(false); /* this will clear any cached values */
-                // Only copy the username and password if they are not fixed.
-                // (If they are fixed, they would be included in the location
-                // identifier and therefore must already match)
-                if (!other.userFixed)
-                    this.user = other.user;
-                if (!other.passwordFixed)
-                    this.password = other.password;
-            }
-        }
-    }
+	 */
+	private void setAuthenticationInformation(CVSRepositoryLocation other) {
+		if (other != this) {
+			// The instances differ so copy from the other location to this one
+			if (other.getUserInfoCached()) {
+				// The user info is cached for the other instance
+				// so null all the values in this instance so the 
+				// information is obtained from the cache
+				this.allowCaching = true;
+				if (!userFixed) this.user = null;
+				if (!passwordFixed) this.password = null;
+			} else {
+				// The user info is not cached for the other instance so
+				// copy the authentication information into this instance
+				setAllowCaching(false); /* this will clear any cached values */
+				// Only copy the username and password if they are not fixed.
+				// (If they are fixed, they would be included in the location
+				// identifier and therefore must already match)
+				if (!other.userFixed)
+					this.user = other.user;
+				if (!other.passwordFixed)
+					this.password = other.password;
+			}
+		}
+	}
 
-    /*
-     * The connection was successfully made. Update the cached
-     * repository location if it is a different instance than
-     * this location.
-     */
-    private void updateCachedLocation() {
-        try {
-            CVSRepositoryLocation known = (CVSRepositoryLocation)KnownRepositories.getInstance().getRepository(getLocation());
-            known.setAuthenticationInformation(this);
-        } catch (CVSException e) {
-            // Log the exception and continue
-            CVSProviderPlugin.log(e);
-        }
-    }
-    
-    /*
+	/*
+	 * The connection was successfully made. Update the cached
+	 * repository location if it is a different instance than
+	 * this location.
+	 */
+	private void updateCachedLocation() {
+		try {
+			CVSRepositoryLocation known = (CVSRepositoryLocation)KnownRepositories.getInstance().getRepository(getLocation());
+			known.setAuthenticationInformation(this);
+		} catch (CVSException e) {
+			// Log the exception and continue
+			CVSProviderPlugin.log(e);
+		}
+	}
+	
+	/*
 	 * Implementation of inherited toString()
 	 */
 	public String toString() {
@@ -948,9 +925,7 @@ public class CVSRepositoryLocation extends PlatformObject implements ICVSReposit
 		}
 		return null;
 	}
-	/*
-	 * @see IUserInfo#setPassword(String)
-	 */
+	@Override
 	public void setPassword(String password) {
 		if (passwordFixed)
 			throw new UnsupportedOperationException();
@@ -962,9 +937,7 @@ public class CVSRepositoryLocation extends PlatformObject implements ICVSReposit
 		previousAuthenticationFailed = false;
 	}
 	
-	/*
-	 * @see IUserInfo#setUsername(String)
-	 */
+	@Override
 	public void setUsername(String user) {
 		if (userFixed)
 			throw new UnsupportedOperationException();
@@ -977,13 +950,13 @@ public class CVSRepositoryLocation extends PlatformObject implements ICVSReposit
 	
 	public void setAllowCaching(boolean value) {
 		allowCaching = value;
-        if (allowCaching) {
-            updateCache();
-        } else {
-        	if (password == null)
-        		password = retrievePassword();
-            removeNode();
-        }
+		if (allowCaching) {
+			updateCache();
+		} else {
+			if (password == null)
+				password = retrievePassword();
+			removeNode();
+		}
 	}
 	
 	public void updateCache() {
@@ -1082,9 +1055,7 @@ public class CVSRepositoryLocation extends PlatformObject implements ICVSReposit
 		}
 	}
 	
-	/**
-	 * @see ICVSRepositoryLocation#flushUserInfo()
-	 */
+	@Override
 	public void flushUserInfo() {
 		removeNode();
 	}
@@ -1190,16 +1161,12 @@ public class CVSRepositoryLocation extends PlatformObject implements ICVSReposit
 		return null;
 	}
 
-	/* (non-Javadoc)
-	 * @see org.eclipse.team.internal.ccvs.core.ICVSRepositoryLocation#getUserAuthenticator()
-	 */
+	@Override
 	public IUserAuthenticator getUserAuthenticator() {
 		return getAuthenticator();
 	}
 	
-	/* (non-Javadoc)
-	 * @see org.eclipse.team.internal.ccvs.core.ICVSRepositoryLocation#setUserAuthenticator()
-	 */
+	@Override
 	public void setUserAuthenticator(IUserAuthenticator authenticator) {
 		CVSRepositoryLocation.authenticator = authenticator;
 	}
@@ -1258,9 +1225,7 @@ public class CVSRepositoryLocation extends PlatformObject implements ICVSReposit
 		}
 	}
 
-	/* (non-Javadoc)
-	 * @see org.eclipse.team.internal.ccvs.core.ICVSRepositoryLocation#getUserInfoCached()
-	 */
+	@Override
 	public boolean getUserInfoCached() {
 		ISecurePreferences node = getCVSNode();
 		if (node == null)
