@@ -148,10 +148,10 @@ public class EclipseSynchronizer implements IFlushOperation {
 	 */
 	public FolderSyncInfo getFolderSync(IContainer folder) throws CVSException {
 		if (folder.getType() == IResource.ROOT || !isValid(folder)) return null;
-        // Do a check outside the lock for any folder sync info
-        FolderSyncInfo info = getSyncInfoCacheFor(folder).getCachedFolderSync(folder, false /* not thread safe */);
-        if (info != null)
-            return info;
+		// Do a check outside the lock for any folder sync info
+		FolderSyncInfo info = getSyncInfoCacheFor(folder).getCachedFolderSync(folder, false /* not thread safe */);
+		if (info != null)
+			return info;
 		try {
 			beginOperation();
 			cacheFolderSync(folder);
@@ -262,10 +262,10 @@ public class EclipseSynchronizer implements IFlushOperation {
 	public byte[] getSyncBytes(IResource resource) throws CVSException {
 		IContainer parent = resource.getParent();
 		if (parent == null || parent.getType() == IResource.ROOT || !isValid(parent)) return null;
-        // Do a quick check outside the lock to see if there are sync butes for the resource.
-        byte[] info = getSyncInfoCacheFor(resource).getCachedSyncBytes(resource, false /* not thread safe */);
-        if (info != null)
-            return info;
+		// Do a quick check outside the lock to see if there are sync butes for the resource.
+		byte[] info = getSyncInfoCacheFor(resource).getCachedSyncBytes(resource, false /* not thread safe */);
+		if (info != null)
+			return info;
 		try {
 			beginOperation();
 			// cache resource sync for siblings, then return for self
@@ -368,20 +368,20 @@ public class EclipseSynchronizer implements IFlushOperation {
 	 */
 	public boolean isIgnored(IResource resource) throws CVSException {
 		if (resource.getType() == IResource.ROOT || 
-		    resource.getType() == IResource.PROJECT || 
-		    ! resource.exists()) {
+			resource.getType() == IResource.PROJECT || 
+			! resource.exists()) {
 			return false;
 		}
 		IContainer parent = resource.getParent();
-        FileNameMatcher matcher = sessionPropertyCache.getFolderIgnores(parent, false /* not thread safe */);
-        if (matcher == null) {
-    		try {
-    			beginOperation();
-                matcher = cacheFolderIgnores(parent);
-    		} finally {
-    			endOperation();
-    		}
-        }
+		FileNameMatcher matcher = sessionPropertyCache.getFolderIgnores(parent, false /* not thread safe */);
+		if (matcher == null) {
+			try {
+				beginOperation();
+				matcher = cacheFolderIgnores(parent);
+			} finally {
+				endOperation();
+			}
+		}
 		return matcher.match(resource.getName());
 	}
 	
@@ -419,9 +419,9 @@ public class EclipseSynchronizer implements IFlushOperation {
 				setCachedFolderIgnores(folder, ignores);
 				SyncFileWriter.writeCVSIgnoreEntries(folder, ignores);
 				// broadcast changes to unmanaged children - they are the only candidates for being ignored
-				List possibleIgnores = new ArrayList();
+				List<IResource> possibleIgnores = new ArrayList<>();
 				accumulateNonManagedChildren(folder, possibleIgnores);
-				ResourceStateChangeListeners.getListener().resourceSyncInfoChanged((IResource[])possibleIgnores.toArray(new IResource[possibleIgnores.size()]));
+				ResourceStateChangeListeners.getListener().resourceSyncInfoChanged(possibleIgnores.toArray(new IResource[possibleIgnores.size()]));
 			} finally {
 				endOperation();
 			}
@@ -499,19 +499,19 @@ public class EclipseSynchronizer implements IFlushOperation {
 	 */
 	public void endBatching(ISchedulingRule rule, IProgressMonitor monitor) throws CVSException {
 		try {
-            resourceLock.release(rule, monitor);
-        } catch (TeamException e) {
-            throw CVSException.wrapException(e);
-        }
+			resourceLock.release(rule, monitor);
+		} catch (TeamException e) {
+			throw CVSException.wrapException(e);
+		}
 	}
 	
-	/* (non-Javadoc)
-	 * 
+	/* 
 	 * Callback which is invoked when the batching resource lock is released 
 	 * or when a flush is requested (see beginBatching(IResource)).
 	 * 
 	 * @see org.eclipse.team.internal.ccvs.core.syncinfo.ReentrantLock.IRunnableOnExit#run(org.eclipse.team.internal.ccvs.core.syncinfo.ReentrantLock.ThreadInfo, org.eclipse.core.runtime.IProgressMonitor)
 	 */
+	@Override
 	public void flush(final ThreadInfo info, IProgressMonitor monitor) throws CVSException {
 		if (info != null && !info.isEmpty()) {
 			try {
@@ -532,21 +532,21 @@ public class EclipseSynchronizer implements IFlushOperation {
 	 */
 	private void beginOperation() {
 		try {
-            // Do not try to acquire the lock if the resources tree is locked
-            // The reason for this is that during the resource delta phase (i.e. when the tree is locked)
-            // the workspace lock is held. If we obtain our lock, there is 
-            // a chance of dealock. It is OK if we don't as we are still protected
-            // by scheduling rules and the workspace lock.
-            if (ResourcesPlugin.getWorkspace().isTreeLocked()) return;
-        } catch (RuntimeException e) {
-		    // If we are not active, throw a cancel. Otherwise, propogate it.
-		    // (see bug 78303)
-		    if (Platform.getBundle(CVSProviderPlugin.ID).getState() == Bundle.ACTIVE) {
-		        throw e;
-		    } else {
-		        throw new OperationCanceledException();
-		    }
-        }
+			// Do not try to acquire the lock if the resources tree is locked
+			// The reason for this is that during the resource delta phase (i.e. when the tree is locked)
+			// the workspace lock is held. If we obtain our lock, there is 
+			// a chance of dealock. It is OK if we don't as we are still protected
+			// by scheduling rules and the workspace lock.
+			if (ResourcesPlugin.getWorkspace().isTreeLocked()) return;
+		} catch (RuntimeException e) {
+			// If we are not active, throw a cancel. Otherwise, propogate it.
+			// (see bug 78303)
+			if (Platform.getBundle(CVSProviderPlugin.ID).getState() == Bundle.ACTIVE) {
+				throw e;
+			} else {
+				throw new OperationCanceledException();
+			}
+		}
 		lock.acquire();
 	}
 	
@@ -555,17 +555,17 @@ public class EclipseSynchronizer implements IFlushOperation {
 	 */
 	private void endOperation() {
 		try {
-            // See beginOperation() for a description of why the lock is not obtained when the tree is locked
-            if (ResourcesPlugin.getWorkspace().isTreeLocked()) return;
-        } catch (RuntimeException e) {
-		    // If we are not active, throw a cancel. Otherwise, propogate it.
-		    // (see bug 78303)
-		    if (Platform.getBundle(CVSProviderPlugin.ID).getState() == Bundle.ACTIVE) {
-		        throw e;
-		    } else {
-		        throw new OperationCanceledException();
-		    }
-        }
+			// See beginOperation() for a description of why the lock is not obtained when the tree is locked
+			if (ResourcesPlugin.getWorkspace().isTreeLocked()) return;
+		} catch (RuntimeException e) {
+			// If we are not active, throw a cancel. Otherwise, propogate it.
+			// (see bug 78303)
+			if (Platform.getBundle(CVSProviderPlugin.ID).getState() == Bundle.ACTIVE) {
+				throw e;
+			} else {
+				throw new OperationCanceledException();
+			}
+		}
 		lock.release();
 	}
 	
@@ -595,8 +595,8 @@ public class EclipseSynchronizer implements IFlushOperation {
 					// Flush changes to disk
 					resourceLock.flush(Policy.subMonitorFor(monitor, 8));
 				} catch (TeamException e) {
-				    throw CVSException.wrapException(e);
-                } finally {
+					throw CVSException.wrapException(e);
+				} finally {
 					// Purge the in-memory cache
 					sessionPropertyCache.purgeCache(root, deep);
 				}
@@ -638,60 +638,60 @@ public class EclipseSynchronizer implements IFlushOperation {
 	public void ignoreFilesChanged(IContainer[] roots) throws CVSException {
 		for (int i = 0; i < roots.length; i++) {
 			IContainer container = roots[i];
-            if (container.exists()) {
-    			ISchedulingRule rule = null;
-    			try {
-    				Set changed = new HashSet();
-    				rule = beginBatching(container, null);
-    				try {
-    					beginOperation();
-                        
-                        // Record the previous ignore pattterns
-                        FileNameMatcher oldIgnores = null;
-                        if (sessionPropertyCache.isFolderSyncInfoCached(container)) {
-                            oldIgnores = cacheFolderIgnores(container);
-                        }
-                        
-                        // Purge the cached state for direct children of the container
-    					changed.addAll(Arrays.asList(
-    						sessionPropertyCache.purgeCache(container, oldIgnores == null /*flush deeply if the old patterns are not known*/)));
-                        
-                        // Purge the state for any children of previously ignored containers
-                        if (oldIgnores != null) {
-                            FileNameMatcher newIgnores = cacheFolderIgnores(container);
-                            try {
-                                IResource[] members = container.members();
-                                for (int j = 0; j < members.length; j++) {
-                                    IResource resource = members[j];
-                                    if (resource.getType() == IResource.FOLDER) {
-                                        String name = resource.getName();
-                                        if (oldIgnores.match(name) && !newIgnores.match(name)) {
-                                            changed.addAll(Arrays.asList(
-                                                    sessionPropertyCache.purgeCache((IContainer)resource, true /*flush deeply*/)));
-                                        }
-                                    }
-                                }
-                            } catch (CoreException e) {
-                                // Just log and continue
-                                CVSProviderPlugin.log(e);
-                            }
-                        }
-    				} finally {
-    					endOperation();
-    				}
-    				if (!changed.isEmpty()) {
-    					ResourceStateChangeListeners.getListener().resourceSyncInfoChanged(
-    						(IResource[]) changed.toArray(new IResource[changed.size()]));
-    				}
-    			} finally {
-    				if (rule != null) endBatching(rule, null);
-    			}
-            }
+			if (container.exists()) {
+				ISchedulingRule rule = null;
+				try {
+					Set<IResource> changed = new HashSet<>();
+					rule = beginBatching(container, null);
+					try {
+						beginOperation();
+						
+						// Record the previous ignore pattterns
+						FileNameMatcher oldIgnores = null;
+						if (sessionPropertyCache.isFolderSyncInfoCached(container)) {
+							oldIgnores = cacheFolderIgnores(container);
+						}
+						
+						// Purge the cached state for direct children of the container
+						changed.addAll(Arrays.asList(
+							sessionPropertyCache.purgeCache(container, oldIgnores == null /*flush deeply if the old patterns are not known*/)));
+						
+						// Purge the state for any children of previously ignored containers
+						if (oldIgnores != null) {
+							FileNameMatcher newIgnores = cacheFolderIgnores(container);
+							try {
+								IResource[] members = container.members();
+								for (int j = 0; j < members.length; j++) {
+									IResource resource = members[j];
+									if (resource.getType() == IResource.FOLDER) {
+										String name = resource.getName();
+										if (oldIgnores.match(name) && !newIgnores.match(name)) {
+											changed.addAll(Arrays.asList(
+													sessionPropertyCache.purgeCache((IContainer)resource, true /*flush deeply*/)));
+										}
+									}
+								}
+							} catch (CoreException e) {
+								// Just log and continue
+								CVSProviderPlugin.log(e);
+							}
+						}
+					} finally {
+						endOperation();
+					}
+					if (!changed.isEmpty()) {
+						ResourceStateChangeListeners.getListener().resourceSyncInfoChanged(
+							changed.toArray(new IResource[changed.size()]));
+					}
+				} finally {
+					if (rule != null) endBatching(rule, null);
+				}
+			}
 		}
 	}
 	
 	public void syncFilesChangedExternally(IContainer[] changedMetaFiles, IFile[] externalDeletions) throws CVSException {
-		List changed = new ArrayList();
+		List<IResource> changed = new ArrayList<>();
 		for (int i = 0; i < changedMetaFiles.length; i++) {
 			IContainer container = changedMetaFiles[i];
 			if (!isWithinActiveOperationScope(container)) {
@@ -708,7 +708,7 @@ public class EclipseSynchronizer implements IFlushOperation {
 		}
 		if (!changed.isEmpty()) {
 			ResourceStateChangeListeners.getListener().externalSyncInfoChange(
-					(IResource[]) changed.toArray(new IResource[changed.size()]));
+					changed.toArray(new IResource[changed.size()]));
 		}
 	}
 	
@@ -947,18 +947,18 @@ public class EclipseSynchronizer implements IFlushOperation {
 		if (threadInfo.isEmpty()) {
 			return SyncInfoCache.STATUS_OK;
 		}
-		List errors = new ArrayList();
+		List<IStatus> errors = new ArrayList<>();
 		try {
 			/*** prepare operation ***/
 			// find parents of changed resources
 			IResource[] changedResources = threadInfo.getChangedResources();
 			IContainer[] changedFolders;
 			if (threadInfo instanceof CVSThreadInfo) {
-			    changedFolders = ((CVSThreadInfo)threadInfo).getChangedFolders();
+				changedFolders = ((CVSThreadInfo)threadInfo).getChangedFolders();
 			} else {
-			    changedFolders = new IContainer[0];
+				changedFolders = new IContainer[0];
 			}
-			Set dirtyParents = new HashSet();
+			Set<IContainer> dirtyParents = new HashSet<>();
 			for (int i = 0; i < changedResources.length; i++) {
 				IResource resource = changedResources[i];
 				IContainer folder = resource.getParent();
@@ -981,7 +981,7 @@ public class EclipseSynchronizer implements IFlushOperation {
 				IContainer folder = changedFolders[i];
 				if (folder.exists() && folder.getType() != IResource.ROOT) {
 					try {
-                        beginOperation();
+						beginOperation();
 						FolderSyncInfo info = sessionPropertyCache.getCachedFolderSync(folder, true);
 						// Do not write the folder sync for linked resources
 						if (info == null) {
@@ -1002,8 +1002,8 @@ public class EclipseSynchronizer implements IFlushOperation {
 						}
 						errors.add(e.getStatus());
 					} finally {
-                        endOperation();
-                    }
+						endOperation();
+					}
 				}
 				monitor.worked(1);
 			}
@@ -1017,8 +1017,8 @@ public class EclipseSynchronizer implements IFlushOperation {
 				if (folder.exists() && folder.getType() != IResource.ROOT) {
 					// write sync info for all children in one go
 					try {
-                        beginOperation();
-						List infos = new ArrayList();
+						beginOperation();
+						List<byte[]> infos = new ArrayList<>();
 						IResource[] children = folder.members(true);
 						for (int i = 0; i < children.length; i++) {
 							IResource resource = children[i];
@@ -1030,7 +1030,7 @@ public class EclipseSynchronizer implements IFlushOperation {
 						// do not overwrite the sync info for linked resources
 						if (infos.size() > 0 || !isLinkedResource(folder))
 							SyncFileWriter.writeAllResourceSync(folder,
-								(byte[][]) infos.toArray(new byte[infos.size()][]));
+								infos.toArray(new byte[infos.size()][]));
 					} catch(CVSException e) {
 						try {
 							sessionPropertyCache.purgeCache(folder, false /* depth 1 */);
@@ -1046,19 +1046,19 @@ public class EclipseSynchronizer implements IFlushOperation {
 						}							
 						errors.add(e.getStatus());
 					} finally {
-                        endOperation();
-                    }
+						endOperation();
+					}
 				}
 				monitor.worked(1);
 			}
 			
 			/*** broadcast events ***/
 			monitor.subTask(CVSMessages.EclipseSynchronizer_NotifyingListeners); 
-			Set allChanges = new HashSet();
+			Set<IResource> allChanges = new HashSet<>();
 			allChanges.addAll(Arrays.asList(changedResources));
 			allChanges.addAll(Arrays.asList(changedFolders));
 			allChanges.addAll(dirtyParents);	
-			IResource[] resources = (IResource[]) allChanges.toArray(
+			IResource[] resources = allChanges.toArray(
 				new IResource[allChanges.size()]);
 			broadcastResourceStateChanges(resources);
 			if ( ! errors.isEmpty()) {
@@ -1067,7 +1067,7 @@ public class EclipseSynchronizer implements IFlushOperation {
 											CVSMessages.EclipseSynchronizer_ErrorCommitting, 
 											null);
 				for (int i = 0; i < errors.size(); i++) {
-					status.merge((IStatus)errors.get(i));
+					status.merge(errors.get(i));
 				}
 				return status;
 			}
@@ -1114,9 +1114,9 @@ public class EclipseSynchronizer implements IFlushOperation {
 	}
 		
 	/**
- 	 * Sets the resource sync info for the resource; if null, deletes it. Parent
- 	 * must exist and must not be the workspace root. The resource sync info for
- 	 * the children of the parent container MUST ALREADY BE CACHED.
+	 * Sets the resource sync info for the resource; if null, deletes it. Parent
+	 * must exist and must not be the workspace root. The resource sync info for
+	 * the children of the parent container MUST ALREADY BE CACHED.
 	 * 
 	 * @param resource the resource
 	 * @param info the new resource sync info
@@ -1160,11 +1160,11 @@ public class EclipseSynchronizer implements IFlushOperation {
 	 * @param folder the folder to be searched
 	 * @param possibleIgnores the list of IResources that can be ignored
 	 */
-	private void accumulateNonManagedChildren(IContainer folder, List possibleIgnores) throws CVSException {
+	private void accumulateNonManagedChildren(IContainer folder, List<IResource> possibleIgnores) throws CVSException {
 		try {
 			cacheResourceSyncForChildren(folder, true /* can modify workspace */);
 			IResource[] children = folder.members();
-			List folders = new ArrayList();
+			List<IResource> folders = new ArrayList<>();
 			// deal with all files first and then folders to be otimized for caching scheme
 			for (int i = 0; i < children.length; i++) {
 				IResource child = children[i];
@@ -1204,7 +1204,7 @@ public class EclipseSynchronizer implements IFlushOperation {
 			if (info == null) return;
 			infos = new NotifyInfo[] { info };
 		} else {
-			Map infoMap = new HashMap();
+			Map<String, NotifyInfo> infoMap = new HashMap<>();
 			for (int i = 0; i < infos.length; i++) {
 				NotifyInfo notifyInfo = infos[i];
 				infoMap.put(notifyInfo.getName(), notifyInfo);
@@ -1251,7 +1251,7 @@ public class EclipseSynchronizer implements IFlushOperation {
 	public void deleteNotifyInfo(IResource resource) throws CVSException {
 		NotifyInfo[] infos = SyncFileWriter.readAllNotifyInfo(resource.getParent());
 		if (infos == null) return;
-		Map infoMap = new HashMap();
+		Map<String, NotifyInfo> infoMap = new HashMap<>();
 		for (int i = 0; i < infos.length; i++) {
 			NotifyInfo notifyInfo = infos[i];
 			infoMap.put(notifyInfo.getName(), notifyInfo);
@@ -1281,7 +1281,7 @@ public class EclipseSynchronizer implements IFlushOperation {
 		if (infos == null) {
 			infos = new BaserevInfo[] { info };
 		} else {
-			Map infoMap = new HashMap();
+			Map<String, BaserevInfo> infoMap = new HashMap<>();
 			for (int i = 0; i < infos.length; i++) {
 				infoMap.put(infos[i].getName(), infos[i]);
 			}
@@ -1320,7 +1320,7 @@ public class EclipseSynchronizer implements IFlushOperation {
 	public void deleteBaserevInfo(IResource resource) throws CVSException {
 		BaserevInfo[] infos = SyncFileWriter.readAllBaserevInfo(resource.getParent());
 		if (infos == null) return;
-		Map infoMap = new HashMap();
+		Map<String, BaserevInfo> infoMap = new HashMap<>();
 		for (int i = 0; i < infos.length; i++) {
 			infoMap.put(infos[i].getName(), infos[i]);
 		}
@@ -1434,7 +1434,7 @@ public class EclipseSynchronizer implements IFlushOperation {
 	 * thats were the sync info is kept.
 	 */
 	private IContainer[] getParentFolders(IResource[] resources, int depth) throws CVSException {
-		final Set folders = new HashSet();
+		final Set<IResource> folders = new HashSet<>();
 		for (int i = 0; i < resources.length; i++) {
 			IResource resource = resources[i];
 			folders.add(resource.getProject());
@@ -1457,7 +1457,7 @@ public class EclipseSynchronizer implements IFlushOperation {
 				}
 			}
 		}
-		return (IContainer[]) folders.toArray(new IContainer[folders.size()]);
+		return folders.toArray(new IContainer[folders.size()]);
 	}
 	
 	/**
@@ -1523,10 +1523,10 @@ public class EclipseSynchronizer implements IFlushOperation {
 	}
 
 	protected String getDirtyIndicator(IResource resource) throws CVSException {
-        // Do a check outside the lock for the dirty indicator
-        String indicator = getSyncInfoCacheFor(resource).getDirtyIndicator(resource, false /* not thread safe */);
-        if (indicator != null)
-            return indicator;
+		// Do a check outside the lock for the dirty indicator
+		String indicator = getSyncInfoCacheFor(resource).getDirtyIndicator(resource, false /* not thread safe */);
+		if (indicator != null)
+			return indicator;
 		try {
 			beginOperation();
 			return getSyncInfoCacheFor(resource).getDirtyIndicator(resource, true);
@@ -1820,12 +1820,12 @@ public class EclipseSynchronizer implements IFlushOperation {
 	}
 	
 	private ISchedulingRule getProjectRule(IResource[] resources) {
-		HashSet set = new HashSet();
+		HashSet<IProject> set = new HashSet<>();
 		for (int i = 0; i < resources.length; i++) {
 			IResource resource = resources[i];
 			set.add(resource.getProject());
 		}
-		IProject[] projects = (IProject[]) set.toArray(new IProject[set.size()]);
+		IProject[] projects = set.toArray(new IProject[set.size()]);
 		if (projects.length == 1) {
 			return projects[0];
 		}
