@@ -82,10 +82,10 @@ import org.eclipse.team.internal.ccvs.core.util.SyncFileWriter;
 		}
 		return matcher;
 	}
-    
-    /* package */ boolean isIgnoresCached(IContainer container) throws CVSException {
-        return safeGetSessionProperty(container, IGNORE_SYNC_KEY) != null;
-    }
+	
+	/* package */ boolean isIgnoresCached(IContainer container) throws CVSException {
+		return safeGetSessionProperty(container, IGNORE_SYNC_KEY) != null;
+	}
 
 	/*package*/ boolean isFolderSyncInfoCached(IContainer container) throws CVSException {
 		Object info = safeGetSessionProperty(container, FOLDER_SYNC_KEY);
@@ -115,9 +115,9 @@ import org.eclipse.team.internal.ccvs.core.util.SyncFileWriter;
 	 */
 	FolderSyncInfo getCachedFolderSync(IContainer container, boolean threadSafeAccess) throws CVSException {
 		FolderSyncInfo info = (FolderSyncInfo)safeGetSessionProperty(container, FOLDER_SYNC_KEY);
-        // If we are not thread safe, just return whatever was found in the session property
-        if (!threadSafeAccess)
-            return info == NULL_FOLDER_SYNC_INFO ? null : info;
+		// If we are not thread safe, just return whatever was found in the session property
+		if (!threadSafeAccess)
+			return info == NULL_FOLDER_SYNC_INFO ? null : info;
 		if (info == null) {
 			// Defer to the synchronizer in case the folder was recreated
 			info = synchronizerCache.getCachedFolderSync(container, true);
@@ -145,7 +145,7 @@ import org.eclipse.team.internal.ccvs.core.util.SyncFileWriter;
 	/*package*/ IResource[] purgeCache(IContainer container, boolean deep) throws CVSException {
 		if (! container.exists()) return new IResource[0];
 		try {
-			Set flushed = new HashSet();
+			Set<IResource> flushed = new HashSet<>();
 			if (container.getType() != IResource.ROOT) {
 				safeSetSessionProperty(container, IGNORE_SYNC_KEY, null);
 				safeSetSessionProperty(container, FOLDER_SYNC_KEY, null);
@@ -163,7 +163,7 @@ import org.eclipse.team.internal.ccvs.core.util.SyncFileWriter;
 					flushed.addAll(Arrays.asList(flushedChildren));
 				}
 			}
-			return (IResource[]) flushed.toArray(new IResource[flushed.size()]);
+			return flushed.toArray(new IResource[flushed.size()]);
 		} catch (CoreException e) {
 			throw CVSException.wrapException(e);
 		}
@@ -258,10 +258,10 @@ import org.eclipse.team.internal.ccvs.core.util.SyncFileWriter;
 				} else {
 					di = RECOMPUTE_INDICATOR;
 				}
-                // Only set the session property if we are thread safe
-                if (threadSafeAccess) {
-                    setDirtyIndicator(container, di);
-                }
+				// Only set the session property if we are thread safe
+				if (threadSafeAccess) {
+					setDirtyIndicator(container, di);
+				}
 			}
 			return di;
 		} catch (CoreException e) {
@@ -303,14 +303,11 @@ import org.eclipse.team.internal.ccvs.core.util.SyncFileWriter;
 		return true;
 	}
 	
-	/**
-	 * @see org.eclipse.team.internal.ccvs.core.resources.SyncInfoCache#getCachedSyncBytes(org.eclipse.core.resources.IResource, boolean)
-	 */
 	byte[] getCachedSyncBytes(IResource resource, boolean threadSafeAccess) throws CVSException {
 		byte[] bytes = (byte[])safeGetSessionProperty(resource, RESOURCE_SYNC_KEY);
 		// If we are not thread safe, just return whatever was found in the session property
-        if (!threadSafeAccess)
-            return bytes;
+		if (!threadSafeAccess)
+			return bytes;
 		if (bytes == null) {
 			// Defer to the synchronizer in case the file was recreated
 			bytes = synchronizerCache.getCachedSyncBytes(resource, true);
@@ -361,9 +358,6 @@ import org.eclipse.team.internal.ccvs.core.util.SyncFileWriter;
 			}
 		}
 	
-	/**
-	 * @see org.eclipse.team.internal.ccvs.core.resources.SyncInfoCache#setCachedSyncBytes(org.eclipse.core.resources.IResource, byte[])
-	 */
 	void setCachedSyncBytes(IResource resource, byte[] syncBytes, boolean canModifyWorkspace) throws CVSException {
 		// Ensure that the sync bytes do not indicate a deletion
 		if (syncBytes != null && ResourceSyncInfo.isDeletion(syncBytes)) {
@@ -377,21 +371,15 @@ import org.eclipse.team.internal.ccvs.core.util.SyncFileWriter;
 		}
 	}
 	
-	/* (non-Javadoc)
-	 * @see org.eclipse.core.resources.ISaveParticipant#doneSaving(org.eclipse.core.resources.ISaveContext)
-	 */
+	@Override
 	public void doneSaving(ISaveContext context) {
 	}
 
-	/* (non-Javadoc)
-	 * @see org.eclipse.core.resources.ISaveParticipant#prepareToSave(org.eclipse.core.resources.ISaveContext)
-	 */
+	@Override
 	public void prepareToSave(ISaveContext context) throws CoreException {
 	}
 
-	/* (non-Javadoc)
-	 * @see org.eclipse.core.resources.ISaveParticipant#rollback(org.eclipse.core.resources.ISaveContext)
-	 */
+	@Override
 	public void rollback(ISaveContext context) {			
 	}
 
@@ -483,9 +471,7 @@ import org.eclipse.team.internal.ccvs.core.util.SyncFileWriter;
 		}
 	}
 
-	/* (non-Javadoc)
-	 * @see org.eclipse.team.internal.ccvs.core.resources.SyncInfoCache#cachesDirtyState()
-	 */
+	@Override
 	public boolean cachesDirtyState() {
 		return true;
 	}
