@@ -39,10 +39,10 @@ public class ConfigureTagsFromRepoViewOnFolder extends CVSAction {
 	 */
 	@Override
 	protected ICVSRemoteFolder[] getSelectedRemoteFolders() {
-		ArrayList resources = null;
+		ArrayList<Object> resources = null;
 		IStructuredSelection selection = getSelection();
 		if (!selection.isEmpty()) {
-			resources = new ArrayList();
+			resources = new ArrayList<>();
 			Iterator elements = selection.iterator();
 			while (elements.hasNext()) {
 				Object next = elements.next();
@@ -55,14 +55,11 @@ public class ConfigureTagsFromRepoViewOnFolder extends CVSAction {
 			}
 		}
 		if (resources != null && !resources.isEmpty()) {
-			return (ICVSRemoteFolder[])resources.toArray(new ICVSRemoteFolder[resources.size()]);
+			return resources.toArray(new ICVSRemoteFolder[resources.size()]);
 		}
 		return new ICVSRemoteFolder[0];
 	}
 
-	/*
-	 * @see CVSAction@execute(IAction)
-	 */
 	@Override
 	public void execute(IAction action) throws InvocationTargetException, InterruptedException {
 		run((IRunnableWithProgress) monitor -> {
@@ -79,16 +76,11 @@ public class ConfigureTagsFromRepoViewOnFolder extends CVSAction {
 		}, false /* cancelable */, PROGRESS_BUSYCURSOR);
 	}
 
-	/*
-	 * @see TeamAction#isEnabled()
-	 */
 	@Override
 	public boolean isEnabled() {
 		return true;
 	}
-	/**
-	 * @see org.eclipse.team.internal.ccvs.ui.actions.CVSAction#getErrorTitle()
-	 */
+
 	@Override
 	protected String getErrorTitle() {
 		return CVSUIMessages.ConfigureTagsFromRepoViewConfigure_Tag_Error_1; 
