@@ -40,12 +40,9 @@ public abstract class AbstractCommitAction extends CVSModelProviderAction {
 		super(configuration);
 	}
 	
-	/* (non-Javadoc)
-	 * @see org.eclipse.jface.action.Action#run()
-	 */
 	@Override
 	public void execute() {
-    	final List resources = new ArrayList();
+		final List resources = new ArrayList();
 		try {
 			final IStructuredSelection selection = getActualSelection();
 			PlatformUI.getWorkbench().getProgressService().busyCursorWhile(monitor -> {
@@ -64,12 +61,12 @@ public abstract class AbstractCommitAction extends CVSModelProviderAction {
 			Utils.handleError(getConfiguration().getSite().getShell(), e, null, null);
 		}
 		if (!resources.isEmpty() && ((IResource[])resources.get(0)).length > 0) {
-	        Shell shell= getConfiguration().getSite().getShell();
-	        try {
-	            CommitWizard.run(getConfiguration().getSite().getPart(), shell, ((IResource[])resources.get(0)));
-	        } catch (CVSException e) {
-	            CVSUIPlugin.log(e);
-	        }
+			Shell shell= getConfiguration().getSite().getShell();
+			try {
+				CommitWizard.run(getConfiguration().getSite().getPart(), shell, ((IResource[])resources.get(0)));
+			} catch (CVSException e) {
+				CVSUIPlugin.log(e);
+			}
 		}
 	}
 	
@@ -79,8 +76,8 @@ public abstract class AbstractCommitAction extends CVSModelProviderAction {
 
 	protected abstract ResourceTraversal[] getCommitTraversals(IStructuredSelection selection, IProgressMonitor monitor) throws CoreException;
 	
-    public static IResource[] getOutgoingChanges(final IResourceDiffTree tree, ResourceTraversal[] traversals, IProgressMonitor monitor) {
-    	final List resources = new ArrayList();
+	public static IResource[] getOutgoingChanges(final IResourceDiffTree tree, ResourceTraversal[] traversals, IProgressMonitor monitor) {
+		final List<IResource> resources = new ArrayList<>();
 		IDiff[] diffs = tree.getDiffs(traversals);
 		for (int i = 0; i < diffs.length; i++) {
 			IDiff diff = diffs[i];
@@ -90,9 +87,9 @@ public abstract class AbstractCommitAction extends CVSModelProviderAction {
 					resources.add(resource);
 			}
 		}
-		return (IResource[]) resources.toArray(new IResource[resources.size()]);
-    }
-    
+		return resources.toArray(new IResource[resources.size()]);
+	}
+	
 	public static boolean hasLocalChange(IDiff diff) {
 		if (diff instanceof IThreeWayDiff) {
 			IThreeWayDiff twd = (IThreeWayDiff) diff;
