@@ -69,7 +69,7 @@ public class ChangeSetActionProvider extends ResourceModelActionProvider {
 		}
 
 		/* package */void createChangeSet(IDiff[] diffs) {
-            ActiveChangeSet set =  getChangeSetCapability().createChangeSet(getConfiguration(), diffs);
+			ActiveChangeSet set =  getChangeSetCapability().createChangeSet(getConfiguration(), diffs);
 			if (set != null) {
 				getActiveChangeSetManager().add(set);
 			}
@@ -110,8 +110,8 @@ public class ChangeSetActionProvider extends ResourceModelActionProvider {
 
 		private final ActiveChangeSet set;
 
-        public AddToChangeSetAction(ISynchronizePageConfiguration configuration, ActiveChangeSet set, ISelection selection) {
-            super(set == null ? TeamUIMessages.ChangeSetActionGroup_2 : escapeActionText(set.getTitle()), configuration); 
+		public AddToChangeSetAction(ISynchronizePageConfiguration configuration, ActiveChangeSet set, ISelection selection) {
+			super(set == null ? TeamUIMessages.ChangeSetActionGroup_2 : escapeActionText(set.getTitle()), configuration); 
 			this.set = set;
 			selectionChanged(selection);
 		}
@@ -140,13 +140,10 @@ public class ChangeSetActionProvider extends ResourceModelActionProvider {
 
 	private abstract class ChangeSetAction extends BaseSelectionListenerAction {
 
-        public ChangeSetAction(String title, ISynchronizePageConfiguration configuration) {
+		public ChangeSetAction(String title, ISynchronizePageConfiguration configuration) {
 			super(title);
 		}
 
-        /* (non-Javadoc)
-         * @see org.eclipse.ui.actions.BaseSelectionListenerAction#updateSelection(org.eclipse.jface.viewers.IStructuredSelection)
-		 */
 		@Override
 		protected boolean updateSelection(IStructuredSelection selection) {
 			return getSelectedSet() != null;
@@ -175,8 +172,8 @@ public class ChangeSetActionProvider extends ResourceModelActionProvider {
 		@Override
 		public void run() {
 			ActiveChangeSet set = getSelectedSet();
-            if (set == null) return;
-            getChangeSetCapability().editChangeSet(internalGetSynchronizePageConfiguration(), set);
+			if (set == null) return;
+			getChangeSetCapability().editChangeSet(internalGetSynchronizePageConfiguration(), set);
 		}
 	}
 
@@ -249,7 +246,7 @@ public class ChangeSetActionProvider extends ResourceModelActionProvider {
 		public void run() {
 			int sortCriteria = getSortCriteria(internalGetSynchronizePageConfiguration());
 			if (isChecked() && sortCriteria != criteria) {
-			    setSortCriteria(internalGetSynchronizePageConfiguration(), criteria);
+				setSortCriteria(internalGetSynchronizePageConfiguration(), criteria);
 				update();
 				((SynchronizePageConfiguration)internalGetSynchronizePageConfiguration()).getPage().getViewer().refresh();
 			}
@@ -260,7 +257,7 @@ public class ChangeSetActionProvider extends ResourceModelActionProvider {
 		}
 	}
 
-    public static int getSortCriteria(ISynchronizePageConfiguration configuration) {
+	public static int getSortCriteria(ISynchronizePageConfiguration configuration) {
 		int sortCriteria = ChangeSetSorter.DATE;
 		if (configuration != null) {
 			Object o = configuration.getProperty(P_LAST_COMMENTSORT);
@@ -338,7 +335,7 @@ public class ChangeSetActionProvider extends ResourceModelActionProvider {
 	}
 
 	private IResource[] getResources(IDiff[] diffArray) {
-		List result = new ArrayList();
+		List<IResource> result = new ArrayList<>();
 		for (int i = 0; i < diffArray.length; i++) {
 			IDiff diff = diffArray[i];
 			IResource resource = ResourceDiffTree.getResourceFor(diff);
@@ -346,7 +343,7 @@ public class ChangeSetActionProvider extends ResourceModelActionProvider {
 				result.add(resource);
 			}
 		}
-		return (IResource[]) result.toArray(new IResource[result.size()]);
+		return result.toArray(new IResource[result.size()]);
 	}
 
 	@Override
@@ -439,7 +436,7 @@ public class ChangeSetActionProvider extends ResourceModelActionProvider {
 	}
 
 	public ChangeSetCapability getChangeSetCapability() {
-        ISynchronizeParticipant participant = getSynchronizePageConfiguration().getParticipant();
+		ISynchronizeParticipant participant = getSynchronizePageConfiguration().getParticipant();
 		if (participant instanceof IChangeSetProvider) {
 			IChangeSetProvider provider = (IChangeSetProvider) participant;
 			return provider.getChangeSetCapability();
@@ -460,7 +457,7 @@ public class ChangeSetActionProvider extends ResourceModelActionProvider {
 		if (selection instanceof ITreeSelection) {
 			ITreeSelection ts = (ITreeSelection) selection;
 			TreePath[] paths = ts.getPaths();
-			List result = new ArrayList();
+			List<IDiff> result = new ArrayList<>();
 			for (int i = 0; i < paths.length; i++) {
 				TreePath path = paths[i];
 				IDiff[] diffs = getLocalChanges(path);
@@ -469,7 +466,7 @@ public class ChangeSetActionProvider extends ResourceModelActionProvider {
 					result.add(diff);
 				}
 			}
-			return (IDiff[]) result.toArray(new IDiff[result.size()]);
+			return result.toArray(new IDiff[result.size()]);
 		}
 		return new IDiff[0];
 	}
@@ -605,11 +602,11 @@ public class ChangeSetActionProvider extends ResourceModelActionProvider {
 		super.setContext(context);
 		if (context != null) {
 			if (editChangeSet != null)
-		        editChangeSet.selectionChanged((IStructuredSelection)getContext().getSelection());
+				editChangeSet.selectionChanged((IStructuredSelection)getContext().getSelection());
 			if (removeChangeSet != null)
-	            removeChangeSet.selectionChanged((IStructuredSelection)getContext().getSelection());
+				removeChangeSet.selectionChanged((IStructuredSelection)getContext().getSelection());
 			if (makeDefault != null)
-		        makeDefault.selectionChanged((IStructuredSelection)getContext().getSelection());
+				makeDefault.selectionChanged((IStructuredSelection)getContext().getSelection());
 		}
 	}
 
