@@ -87,9 +87,6 @@ public class ModelMergeParticipant extends CVSModelSynchronizeParticipant {
 		return new MergeActionGroup();
 	}
 
-	/* (non-Javadoc)
-	 * @see org.eclipse.team.ui.operations.ModelSynchronizeParticipant#initializeConfiguration(org.eclipse.team.ui.synchronize.ISynchronizePageConfiguration)
-	 */
 	@Override
 	protected void initializeConfiguration(ISynchronizePageConfiguration configuration) {
 		configuration.setProperty(ISynchronizePageConfiguration.P_VIEWER_ID, VIEWER_ID);
@@ -151,7 +148,7 @@ public class ModelMergeParticipant extends CVSModelSynchronizeParticipant {
 			throw new CVSException(NLS.bind(CVSUIMessages.MergeSynchronizeParticipant_10, new String[] { id.toString() })); 
 		}
 		
-		List resources = new ArrayList();
+		List<IResource> resources = new ArrayList<>();
 		for (int i = 0; i < rootNodes.length; i++) {
 			IMemento rootNode = rootNodes[i];
 			IPath path = new Path(rootNode.getString(CTX_ROOT_PATH)); 
@@ -166,7 +163,7 @@ public class ModelMergeParticipant extends CVSModelSynchronizeParticipant {
 		if(resources.isEmpty()) {
 			throw new CVSException(NLS.bind(CVSUIMessages.MergeSynchronizeParticipant_12, new String[] { id.toString() })); 
 		}
-		IResource[] roots = (IResource[]) resources.toArray(new IResource[resources.size()]);
+		IResource[] roots = resources.toArray(new IResource[resources.size()]);
 		return new CVSMergeSubscriber(id, roots, start, end);
 	}
 	
@@ -214,9 +211,6 @@ public class ModelMergeParticipant extends CVSModelSynchronizeParticipant {
 		return MergeSubscriberContext.createContext(manager, subscriber);
 	}
 	
-	/* (non-Javadoc)
-	 * @see org.eclipse.team.ui.synchronize.ISynchronizeParticipant#getName()
-	 */
 	@Override
 	public String getName() {		
 		return NLS.bind(CVSUIMessages.CompareParticipant_0, new String[] { getSubscriber().getName(), Utils.getScopeDescription(getContext().getScope()) });  
