@@ -61,9 +61,6 @@ public class CheckoutIntoOperation extends CheckoutOperation {
 		this.localFolderName = localFolder.getName();
 	}
 	
-	/* (non-Javadoc)
-	 * @see org.eclipse.team.internal.ccvs.ui.operations.CheckoutOperation#getTaskName()
-	 */
 	@Override
 	protected String getTaskName() {
 		ICVSRemoteFolder[] remoteFolders = getRemoteFolders();
@@ -86,9 +83,6 @@ public class CheckoutIntoOperation extends CheckoutOperation {
 		return recursive;
 	}
 	
-	/* (non-Javadoc)
-	 * @see org.eclipse.team.internal.ccvs.ui.operations.CheckoutOperation#checkout(org.eclipse.team.internal.ccvs.core.ICVSRemoteFolder, org.eclipse.core.runtime.IProgressMonitor)
-	 */
 	@Override
 	protected IStatus checkout(final ICVSRemoteFolder folder, IProgressMonitor monitor) throws CVSException {
 		final IStatus[] result = new IStatus[] { null };
@@ -107,9 +101,6 @@ public class CheckoutIntoOperation extends CheckoutOperation {
 		return result[0];
 	}
 	
-	/* (non-Javadoc)
-	 * @see org.eclipse.team.internal.ccvs.ui.operations.CheckoutOperation#checkout(org.eclipse.team.internal.ccvs.core.ICVSRemoteFolder[], org.eclipse.core.runtime.IProgressMonitor)
-	 */
 	@Override
 	protected void checkout(final ICVSRemoteFolder[] folders, IProgressMonitor monitor) throws CVSException {
 		// Batch sync info changes with the CVS synchronizer to optimize cache writing
@@ -131,7 +122,7 @@ public class CheckoutIntoOperation extends CheckoutOperation {
 	 * could expand to multiple local folders witinb the given parent folder.
 	 */
 	private ICVSFolder[] prepareLocalFolders(Session session, ICVSRemoteFolder remoteFolder, ICVSFolder parentFolder, String localFolderName, IProgressMonitor monitor) throws CVSException {
-		Set targetFolderSet = new HashSet();
+		Set<ICVSFolder> targetFolderSet = new HashSet<>();
 		monitor.beginTask(null, 30);
 		if (localFolderName == null) {
 			
@@ -159,7 +150,7 @@ public class CheckoutIntoOperation extends CheckoutOperation {
 			targetFolderSet.add(parentFolder.getFolder(localFolderName));
 		}
 		
-		final ICVSFolder[] targetFolders = (ICVSFolder[]) targetFolderSet.toArray(new ICVSFolder[targetFolderSet.size()]);
+		final ICVSFolder[] targetFolders = targetFolderSet.toArray(new ICVSFolder[targetFolderSet.size()]);
 		
 		// Ensure that the checkout will not conflict with existing resources
 		IStatus status = validateTargetFolders(remoteFolder, targetFolders, Policy.subMonitorFor(monitor, 10));
@@ -259,10 +250,10 @@ public class CheckoutIntoOperation extends CheckoutOperation {
 					FolderSyncInfo info = folder.getFolderSyncInfo();
 					if (info.isSameMapping(remoteInfo)) {
 						throw new CVSException(NLS.bind(CVSUIMessages.CheckoutIntoOperation_mappingAlreadyExists, (new Object[] {
-                        	remoteFolder.getName(), 
-                        	targetFolder.getIResource().getFullPath().toString(),
-                        	resource.getFullPath().toString()
-                        })));
+							remoteFolder.getName(), 
+							targetFolder.getIResource().getFullPath().toString(),
+							resource.getFullPath().toString()
+						})));
 					}
 					folder.acceptChildren(this);
 				}
@@ -341,7 +332,7 @@ public class CheckoutIntoOperation extends CheckoutOperation {
 			}
 			
 			// Add recurse option
-			List localOptions = new ArrayList();
+			List<LocalOption> localOptions = new ArrayList<>();
 			if (!recurse)
 				localOptions.add(Command.DO_NOT_RECURSE);
 			if (localName != null) {
@@ -362,7 +353,7 @@ public class CheckoutIntoOperation extends CheckoutOperation {
 			// Perform the checkout
 			IStatus status = Command.CHECKOUT.execute(session,
 				Command.NO_GLOBAL_OPTIONS,
-				(LocalOption[])localOptions.toArray(new LocalOption[localOptions.size()]),
+				localOptions.toArray(new LocalOption[localOptions.size()]),
 				new String[] { remoteFolder.getRepositoryRelativePath() },
 				null,
 				Policy.subMonitorFor(monitor, 80));
@@ -422,17 +413,14 @@ public class CheckoutIntoOperation extends CheckoutOperation {
 			}
 	}
 	
-	/* (non-Javadoc)
-	 * @see org.eclipse.team.internal.ccvs.ui.operations.CVSOperation#getSchedulingRule()
-	 */
 	@Override
 	protected ISchedulingRule getSchedulingRule() {
 		//use the modfiy rule for the time being
 		//TODO: Just lock the project not the entire workspace (so can't use modifyRule)
 		//since the project already exists 
-		 IProject tempProject = getLocalFolder().getIResource().getProject();
-		 IResourceRuleFactory ruleFactory = ResourcesPlugin.getWorkspace().getRuleFactory();
-		 return ruleFactory.modifyRule(tempProject);
+		IProject tempProject = getLocalFolder().getIResource().getProject();
+		IResourceRuleFactory ruleFactory = ResourcesPlugin.getWorkspace().getRuleFactory();
+		return ruleFactory.modifyRule(tempProject);
 	}
 
 }
