@@ -32,72 +32,57 @@ import org.eclipse.team.internal.ccvs.ui.repo.RepositoryManager;
  */
 public class MultiFolderTagSource extends SingleFolderTagSource {
 
-    private final ICVSFolder[] folders;
+	private final ICVSFolder[] folders;
 
-    /* package */ MultiFolderTagSource(ICVSFolder[] folders) {
-        super(folders[0]);
-        this.folders = folders;
-    }
-    
-    /* (non-Javadoc)
-     * @see org.eclipse.team.internal.ccvs.ui.merge.SingleFolderTagSource#getShortDescription()
-     */
-    @Override
+	/* package */ MultiFolderTagSource(ICVSFolder[] folders) {
+		super(folders[0]);
+		this.folders = folders;
+	}
+	
+	@Override
 	public String getShortDescription() {
-        return NLS.bind(CVSUIMessages.MultiFolderTagSource_0, new String[] { Integer.toString(folders.length) }); 
-    }
-    
-    /* (non-Javadoc)
-     * @see org.eclipse.team.internal.ccvs.ui.merge.TagSource#getTags(int)
-     */
-    @Override
+		return NLS.bind(CVSUIMessages.MultiFolderTagSource_0, new String[] { Integer.toString(folders.length) }); 
+	}
+	
+	@Override
 	public CVSTag[] getTags(int type) {
-        if (type == CVSTag.HEAD || type == BASE) {
-            return super.getTags(type);
-        }
-        Set tags= new HashSet();
-        for (int i= 0; i < folders.length; i++) {
+		if (type == CVSTag.HEAD || type == BASE) {
+			return super.getTags(type);
+		}
+		Set<CVSTag> tags = new HashSet<>();
+		for (int i= 0; i < folders.length; i++) {
 			tags.addAll(Arrays.asList(getTags(folders[i], type)));
 		}
-        return (CVSTag[]) tags.toArray(new CVSTag[tags.size()]);
-    }
-    
-    /* (non-Javadoc)
-     * @see org.eclipse.team.internal.ccvs.ui.tags.SingleFolderTagSource#refresh(boolean, org.eclipse.core.runtime.IProgressMonitor)
-     */
-    @Override
+		return tags.toArray(new CVSTag[tags.size()]);
+	}
+	
+	@Override
 	public CVSTag[] refresh(boolean bestEffort, IProgressMonitor monitor) throws TeamException {
 		monitor.beginTask("", folders.length);  //$NON-NLS-1$
-        Set result= new HashSet();
-    	for (int i= 0; i < folders.length; i++) {
+		Set<CVSTag> result = new HashSet<>();
+		for (int i= 0; i < folders.length; i++) {
 			ICVSFolder folder= folders[i];
 			CVSTag[] tags = CVSUIPlugin.getPlugin().getRepositoryManager().refreshDefinedTags(folder, bestEffort /* recurse */, true /* notify */, Policy.subMonitorFor(monitor, 1));
 			result.addAll(Arrays.asList(tags));
 		}
-    	monitor.done();
-        fireChange();
-        return (CVSTag[]) result.toArray(new CVSTag[result.size()]);
-    }
-    
-    /* (non-Javadoc)
-     * @see org.eclipse.team.internal.ccvs.ui.tags.SingleFolderTagSource#getCVSResources()
-     */
-    @Override
+		monitor.done();
+		fireChange();
+		return result.toArray(new CVSTag[result.size()]);
+	}
+	
+	@Override
 	public ICVSResource[] getCVSResources() {
-        return folders;
-    }
-    
-    public ICVSFolder[] getFolders(){
-    	return folders;
-    }
-    
-    /* (non-Javadoc)
-     * @see org.eclipse.team.internal.ccvs.ui.merge.TagSource#commit(org.eclipse.team.internal.ccvs.core.CVSTag[], boolean, org.eclipse.core.runtime.IProgressMonitor)
-     */
-    @Override
+		return folders;
+	}
+	
+	public ICVSFolder[] getFolders(){
+		return folders;
+	}
+	
+	@Override
 	public void commit(final CVSTag[] tags, final boolean replace, IProgressMonitor monitor) throws CVSException {
 		try {
-            final RepositoryManager manager = CVSUIPlugin.getPlugin().getRepositoryManager();	
+			final RepositoryManager manager = CVSUIPlugin.getPlugin().getRepositoryManager();	
 			manager.run(monitor1 -> {
 				try {
 					ICVSFolder[] folders = getFolders();
@@ -112,11 +97,11 @@ public class MultiFolderTagSource extends SingleFolderTagSource {
 					throw new InvocationTargetException(e);
 				}
 			}, monitor);
-        } catch (InvocationTargetException e) {
-            throw CVSException.wrapException(e);
-        } catch (InterruptedException e) {
-            // Ignore
-        }
-        fireChange();
-    }
+		} catch (InvocationTargetException e) {
+			throw CVSException.wrapException(e);
+		} catch (InterruptedException e) {
+			// Ignore
+		}
+		fireChange();
+	}
 }
