@@ -82,15 +82,12 @@ public class CheckoutAsProjectSelectionPage extends CVSWizardPage {
 		return remoteFolders[0].getFolderSyncInfo().getRoot();
 	}
 	
-	/**
-	 * @see org.eclipse.jface.dialogs.IDialogPage#createControl(org.eclipse.swt.widgets.Composite)
-	 */
 	@Override
 	public void createControl(Composite parent) {
 		Composite composite= createComposite(parent, 2, false);
 		setControl(composite);
 		
-        PlatformUI.getWorkbench().getHelpSystem().setHelp(composite, IHelpContextIds.CHECKOUT_PROJECT_SELECTION_PAGE);
+		PlatformUI.getWorkbench().getHelpSystem().setHelp(composite, IHelpContextIds.CHECKOUT_PROJECT_SELECTION_PAGE);
 		
 		if (isSingleFolder()) {
 			createLabel(composite, CVSUIMessages.CheckoutAsProjectSelectionPage_name); 
@@ -126,7 +123,7 @@ public class CheckoutAsProjectSelectionPage extends CVSWizardPage {
 		initializeValues();
 		updateWidgetEnablements();
 		tree.getControl().setFocus();
-        Dialog.applyDialogFont(parent);
+		Dialog.applyDialogFont(parent);
 	}
 
 	/**
@@ -196,7 +193,7 @@ public class CheckoutAsProjectSelectionPage extends CVSWizardPage {
 	 * @return IResource
 	 */
 	private IProject[] getProjects(String root, boolean unshared) throws CVSException {
-		List validTargets = new ArrayList();
+		List<IProject> validTargets = new ArrayList<>();
 		try {
 			IResource[] projects = ResourcesPlugin.getWorkspace().getRoot().members();
 			for (int i = 0; i < projects.length; i++) {
@@ -220,7 +217,7 @@ public class CheckoutAsProjectSelectionPage extends CVSWizardPage {
 		} catch (CoreException e) {
 			throw CVSException.wrapException(e);
 		}
-		return (IProject[]) validTargets.toArray(new IProject[validTargets.size()]);
+		return validTargets.toArray(new IProject[validTargets.size()]);
 	}
 	
 	public IContainer getLocalFolder() {
