@@ -61,8 +61,8 @@ public class RestoreFromRepositoryFileSelectionPage extends CVSWizardPage {
 	private IContainer folder;
 	private IFile selectedFile;
 	private ILogEntry selectedRevision;
-	private Map entriesCache = new HashMap();
-	private Map filesToRestore = new HashMap();
+	private Map<IFile, ILogEntry[]> entriesCache = new HashMap<>();
+	private Map<IFile, Object> filesToRestore = new HashMap<>();
 
 	private static final int WIZARD_WIDTH = 550;
 	
@@ -121,15 +121,12 @@ public class RestoreFromRepositoryFileSelectionPage extends CVSWizardPage {
 		super(pageName, title, titleImage, description);
 	}
 
-	/**
-	 * @see org.eclipse.jface.dialogs.IDialogPage#createControl(org.eclipse.swt.widgets.Composite)
-	 */
 	@Override
 	public void createControl(Composite parent) {
 		Composite composite= createComposite(parent, 1, false);
 		setControl(composite);
 		
-        PlatformUI.getWorkbench().getHelpSystem().setHelp(composite, IHelpContextIds.RESTORE_FROM_REPOSITORY_FILE_SELECTION_PAGE);
+		PlatformUI.getWorkbench().getHelpSystem().setHelp(composite, IHelpContextIds.RESTORE_FROM_REPOSITORY_FILE_SELECTION_PAGE);
 		
 		// Top and bottom panes: top is the two selection panes, bottom is the file content viewer
 		Splitter vsplitter= new Splitter(composite,  SWT.VERTICAL);
@@ -168,7 +165,7 @@ public class RestoreFromRepositoryFileSelectionPage extends CVSWizardPage {
 
 		initializeValues();
 		updateWidgetEnablements();
-        Dialog.applyDialogFont(parent);
+		Dialog.applyDialogFont(parent);
 	}
 
 	protected CheckboxTableViewer createRevisionSelectionTable(CompareViewerPane composite, HistoryTableProvider tableProvider) {
@@ -435,7 +432,7 @@ public class RestoreFromRepositoryFileSelectionPage extends CVSWizardPage {
 	}
 
 	private ILogEntry[] getSelectedEntries() {
-		return (ILogEntry[])entriesCache.get(selectedFile);
+		return entriesCache.get(selectedFile);
 	}
 	
 	private IStorage getStorageFromLogEntry(final ILogEntry logEntry) {
