@@ -16,7 +16,9 @@ package org.eclipse.team.internal.ui.synchronize;
 import java.util.HashMap;
 import java.util.Map;
 
-import org.eclipse.core.runtime.*;
+import org.eclipse.core.runtime.ISafeRunnable;
+import org.eclipse.core.runtime.ListenerList;
+import org.eclipse.core.runtime.SafeRunner;
 import org.eclipse.jface.action.IMenuManager;
 import org.eclipse.jface.operation.IRunnableContext;
 import org.eclipse.jface.util.IPropertyChangeListener;
@@ -28,7 +30,12 @@ import org.eclipse.team.core.mapping.IResourceDiff;
 import org.eclipse.team.core.synchronize.SyncInfoSet;
 import org.eclipse.team.internal.ui.TeamUIPlugin;
 import org.eclipse.team.internal.ui.mapping.CommonViewerAdvisor;
-import org.eclipse.team.ui.synchronize.*;
+import org.eclipse.team.ui.synchronize.ISynchronizeModelElement;
+import org.eclipse.team.ui.synchronize.ISynchronizePage;
+import org.eclipse.team.ui.synchronize.ISynchronizePageConfiguration;
+import org.eclipse.team.ui.synchronize.ISynchronizePageSite;
+import org.eclipse.team.ui.synchronize.ISynchronizeParticipant;
+import org.eclipse.team.ui.synchronize.SynchronizePageActionGroup;
 import org.eclipse.ui.IActionBars;
 import org.eclipse.ui.actions.ActionContext;
 
@@ -109,10 +116,10 @@ public class SynchronizePageConfiguration extends SynchronizePageActionGroup imp
 
 	public static final int CHECKBOX = TreeViewerAdvisor.CHECKBOX;
 
-    // State flags
-    private static final int UNINITIALIZED = 0;
-    private static final int INITIALIZED = 1;
-    private static final int DISPOSED = 2;
+	// State flags
+	private static final int UNINITIALIZED = 0;
+	private static final int INITIALIZED = 1;
+	private static final int DISPOSED = 2;
 
 	private ISynchronizeParticipant participant;
 	private ISynchronizePageSite site;
@@ -185,25 +192,25 @@ public class SynchronizePageConfiguration extends SynchronizePageActionGroup imp
 
 	@Override
 	public void addActionContribution(SynchronizePageActionGroup contribution) {
-        int currentActionState;
+		int currentActionState;
 		synchronized(actionContributions) {
-            // Determine the action state while locked so we handle the addition properly below
-            currentActionState = actionState;
-            if (currentActionState != DISPOSED)
-                actionContributions.add(contribution);
+			// Determine the action state while locked so we handle the addition properly below
+			currentActionState = actionState;
+			if (currentActionState != DISPOSED)
+				actionContributions.add(contribution);
 		}
 		if (currentActionState == INITIALIZED) {
-            // This is tricky because we are doing the initialize while not locked.
-            // It is possible that another thread is concurrently disposing the contributions
-            // but we can't lock while calling client code. We'll change for DISPOSE after
-            // we initialize and, if we are disposed, we dispose this one, just in case.
+			// This is tricky because we are doing the initialize while not locked.
+			// It is possible that another thread is concurrently disposing the contributions
+			// but we can't lock while calling client code. We'll change for DISPOSE after
+			// we initialize and, if we are disposed, we dispose this one, just in case.
 			contribution.initialize(this);
-            if (actionState == DISPOSED) {
-                contribution .dispose();
-            }
+			if (actionState == DISPOSED) {
+				contribution .dispose();
+			}
 		} else if (currentActionState == DISPOSED) {
-            contribution.dispose();
-        }
+			contribution.dispose();
+		}
 	}
 
 	@Override
@@ -237,16 +244,16 @@ public class SynchronizePageConfiguration extends SynchronizePageActionGroup imp
 	@Override
 	public void initialize(final ISynchronizePageConfiguration configuration) {
 		super.initialize(configuration);
-        // need to synchronize here to ensure that actions that are added concurrently also get initialized
-        final Object[] listeners;
-        synchronized(actionContributions) {
-            if (actionState != UNINITIALIZED) {
-                // Initialization has already taken place so just return.
-                return;
-            }
-            actionState = INITIALIZED;
-            listeners = actionContributions.getListeners();
-        }
+		// need to synchronize here to ensure that actions that are added concurrently also get initialized
+		final Object[] listeners;
+		synchronized(actionContributions) {
+			if (actionState != UNINITIALIZED) {
+				// Initialization has already taken place so just return.
+				return;
+			}
+			actionState = INITIALIZED;
+			listeners = actionContributions.getListeners();
+		}
 		for (int i= 0; i < listeners.length; i++) {
 			final SynchronizePageActionGroup contribution = (SynchronizePageActionGroup)listeners[i];
 			SafeRunner.run(new ISafeRunnable() {
@@ -265,10 +272,10 @@ public class SynchronizePageConfiguration extends SynchronizePageActionGroup imp
 	@Override
 	public void setContext(final ActionContext context) {
 		super.setContext(context);
-        final Object[] listeners;
-        synchronized(actionContributions) {
-            listeners = actionContributions.getListeners();
-        }
+		final Object[] listeners;
+		synchronized(actionContributions) {
+			listeners = actionContributions.getListeners();
+		}
 		for (int i= 0; i < listeners.length; i++) {
 			final SynchronizePageActionGroup contribution = (SynchronizePageActionGroup)listeners[i];
 			SafeRunner.run(new ISafeRunnable() {
@@ -291,10 +298,10 @@ public class SynchronizePageConfiguration extends SynchronizePageActionGroup imp
 	 */
 	@Override
 	public void fillContextMenu(final IMenuManager manager) {
-        final Object[] listeners;
-        synchronized(actionContributions) {
-            listeners = actionContributions.getListeners();
-        }
+		final Object[] listeners;
+		synchronized(actionContributions) {
+			listeners = actionContributions.getListeners();
+		}
 		for (int i= 0; i < listeners.length; i++) {
 			final SynchronizePageActionGroup contribution = (SynchronizePageActionGroup)listeners[i];
 			SafeRunner.run(new ISafeRunnable() {
@@ -319,10 +326,10 @@ public class SynchronizePageConfiguration extends SynchronizePageActionGroup imp
 		if (actionState == UNINITIALIZED) {
 			initialize(this);
 		}
-        final Object[] listeners;
-        synchronized(actionContributions) {
-            listeners = actionContributions.getListeners();
-        }
+		final Object[] listeners;
+		synchronized(actionContributions) {
+			listeners = actionContributions.getListeners();
+		}
 		for (int i= 0; i < listeners.length; i++) {
 			final SynchronizePageActionGroup contribution = (SynchronizePageActionGroup)listeners[i];
 			SafeRunner.run(new ISafeRunnable() {
@@ -340,10 +347,10 @@ public class SynchronizePageConfiguration extends SynchronizePageActionGroup imp
 
 	@Override
 	public void updateActionBars() {
-        final Object[] listeners;
-        synchronized(actionContributions) {
-            listeners = actionContributions.getListeners();
-        }
+		final Object[] listeners;
+		synchronized(actionContributions) {
+			listeners = actionContributions.getListeners();
+		}
 		for (int i= 0; i < listeners.length; i++) {
 			final SynchronizePageActionGroup contribution = (SynchronizePageActionGroup)listeners[i];
 			SafeRunner.run(new ISafeRunnable() {
@@ -361,10 +368,10 @@ public class SynchronizePageConfiguration extends SynchronizePageActionGroup imp
 
 	@Override
 	public void modelChanged(final ISynchronizeModelElement root) {
-        final Object[] listeners;
-        synchronized(actionContributions) {
-            listeners = actionContributions.getListeners();
-        }
+		final Object[] listeners;
+		synchronized(actionContributions) {
+			listeners = actionContributions.getListeners();
+		}
 		for (int i= 0; i < listeners.length; i++) {
 			final SynchronizePageActionGroup contribution = (SynchronizePageActionGroup)listeners[i];
 			SafeRunner.run(new ISafeRunnable() {
@@ -383,11 +390,11 @@ public class SynchronizePageConfiguration extends SynchronizePageActionGroup imp
 	@Override
 	public void dispose() {
 		super.dispose();
-        final Object[] listeners;
-        synchronized(actionContributions) {
-            listeners = actionContributions.getListeners();
-            actionState = DISPOSED;
-        }
+		final Object[] listeners;
+		synchronized(actionContributions) {
+			listeners = actionContributions.getListeners();
+			actionState = DISPOSED;
+		}
 		for (int i= 0; i < listeners.length; i++) {
 			final SynchronizePageActionGroup contribution = (SynchronizePageActionGroup)listeners[i];
 			SafeRunner.run(new ISafeRunnable() {
